@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/bin/sh
 
 # set -x
 
@@ -17,7 +17,7 @@ huge=$tmp/huge.png
 echo -n "testing vipsthumbnail ... "
 rm -f $tmp/x.png
 vipsthumbnail $huge -o $tmp/x.png
-if ! vipsheader $tmp/x.png &> /dev/null ; then
+if ! vipsheader $tmp/x.png > /dev/null 2>&1 ; then
 	echo "vipsthumbnail failed in basic mode"
 	exit 1
 fi
@@ -32,7 +32,7 @@ export TMPDIR=$tmp/readonly
 echo -n "testing vipsthumbnail does not make temps ... "
 rm -f $tmp/x.png
 vipsthumbnail $huge -o $tmp/x.png
-if ! vipsheader $tmp/x.png &> /dev/null ; then
+if ! vipsheader $tmp/x.png > /dev/null 2>&1 ; then
 	echo "vipsthumbnail made a temp"
 	exit 1
 fi
@@ -41,7 +41,7 @@ echo "ok"
 echo -n "testing shrink does not make temps ... "
 rm -f $tmp/x.png
 vips shrink $huge $tmp/x.png 230 230 
-if ! vipsheader $tmp/x.png &> /dev/null; then
+if ! vipsheader $tmp/x.png > /dev/null 2>&1 ; then
 	echo "shrink made a temp"
 	exit 1
 fi
